
// $Id: Backup.cpp,v 1.7 2014/04/29 17:08:08 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Backup.h"
#include "Debug.h"
#include "XmlDef.h"

//______________________________________________________________________
Backup::Backup( const QDomElement& element ):
    Counter( "Backup" ),
    valid_( true )
{
    Debug::Throw( "Backup::Backup.\n" );

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( int i=0; i<attributes.count(); i++ )
    {
        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        if( attribute.name() == Xml::Creation ) setCreation( attribute.value().toUInt() );
        else if( attribute.name() == Xml::File ) setFile( File( attribute.value() ) );
        else Debug::Throw(0) << "Backup::Backup - unknown attribute name: " << attribute.name() << endl;
    }
}

//______________________________________________________________________
QDomElement Backup::domElement( QDomDocument& document ) const
{
    Debug::Throw( "Backup::domElement.\n" );
    QDomElement out( document.createElement( Xml::BackupMask ) );
    out.setAttribute( Xml::Creation, QString::number( creation() ) );
    out.setAttribute( Xml::File, file() );
    return out;
}
